# Generated by Django 5.2.9 on 2026-01-02 09:32

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ("django_cfg_accounts", "0011_delete_twofactorsettings"),
    ]

    operations = [
        migrations.AddField(
            model_name="customuser",
            name="is_test_account",
            field=models.BooleanField(
                default=False,
                help_text="Test account bypasses OTP with static code (for App Store review, etc.)",
            ),
        ),
    ]
