export default {
  'index': { display: 'hidden' },
  'overview': 'Overview',
  'django-cf': 'Cloudflare D1',
  'django-monitor': 'Monitor',
  'streamlit-admin': 'Streamlit Admin',
  'django-codegen': 'Code Generation',
  'currency': 'Currency Conversion',
  'django-cleanup': 'File Cleanup',
  'django-client': 'Django Client',
  'email': 'Email System',
  'encryption': 'API Encryption',
  'fastapi-orm': 'FastAPI ORM',
  'health': 'Health Monitoring',
  'llm': 'LLM Integration',
  'telegram': 'Telegram Bot',
  'import-export': 'Import/Export',
  'django-admin': 'Django Admin',
  'unfold': 'Django Unfold',
  'og-image': 'OG Images'
}
