export default {
  'index': { display: 'hidden' },
  'drf-viewsets': 'ViewSets & Serializers',
  'drf-array-responses': 'Array Responses',
  'drf-nested-serializers': 'Nested Serializers & allOf',
  'drf-pagination': 'Pagination',
  'drf-pydantic-responses': 'Pydantic v2 Response Schemas',
}
