export default {
  'getting-started': 'Getting Started',
  'core-concepts': 'Core Concepts',
  'fundamentals': 'Fundamentals',
  'features': 'Features',
  'cli': 'CLI Tools',
  'guides': 'Guides & Examples',
  'deployment': 'Deployment',
  'business': 'Business',
  'api': 'API Reference',
  '---': {
    type: 'separator'
  },
  'updates': 'Updates'
}
