export default {
  'index': { display: 'hidden' },
  'overview': 'Overview',
  'auth': { display: 'hidden' },
  'auth-system': { display: 'hidden' },
  'oauth': { display: 'hidden' },
  'django-rq': 'Django-RQ',
  'centrifugo': 'Centrifugo WebSocket',
  'grpc': 'gRPC Integration',
  'ngrok': 'Ngrok Integration',
  'database-backup': 'Database Backup',
  'patterns': 'Integration Patterns'
}
