export default {
  'index': { display: 'hidden' },
  'intro': 'Introduction',
  'why-django-cfg': 'Why Django-CFG',
  'django-cfg-vs-alternatives': 'Django-CFG vs Alternatives',
  'installation': 'Installation',
  'configuration': 'Configuration',
  'first-project': 'First Project',
}
