# Generated by Django 5.2.9 on 2026-01-06 14:28

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ("django_cfg_accounts", "0012_customuser_is_test_account"),
    ]

    operations = [
        migrations.AddField(
            model_name="customuser",
            name="deleted_at",
            field=models.DateTimeField(
                blank=True,
                help_text="When set, account is considered deleted (soft delete)",
                null=True,
            ),
        ),
    ]
