# Generated by Django 5.2.6 on 2025-09-15 18:46

from django.db import migrations, models


class Migration(migrations.Migration):
    dependencies = [
        ("django_cfg_accounts", "0001_initial"),
    ]

    operations = [
        migrations.RemoveIndex(
            model_name="otpsecret",
            name="django_cfg__email_f595c8_idx",
        ),
        migrations.RemoveField(
            model_name="otpsecret",
            name="email",
        ),
        migrations.AddField(
            model_name="customuser",
            name="phone_verified",
            field=models.BooleanField(
                default=False, help_text="Whether the phone number has been verified"
            ),
        ),
        migrations.AddField(
            model_name="otpsecret",
            name="channel_type",
            field=models.CharField(
                choices=[("email", "Email"), ("phone", "Phone")], default="email", max_length=10
            ),
        ),
        migrations.AddField(
            model_name="otpsecret",
            name="recipient",
            field=models.CharField(
                blank=True, db_index=True, help_text="Email address or phone number", max_length=255
            ),
        ),
        migrations.AddIndex(
            model_name="otpsecret",
            index=models.Index(
                fields=["recipient", "channel_type", "is_used", "expires_at"],
                name="django_cfg__recipie_f9f5aa_idx",
            ),
        ),
    ]
