export default {
  'index': 'Overview',
  'environment': 'Environment',
  'database': 'Database',
  'cache': 'Cache',
  'email': 'Email',
  'security': 'Security',
  'django-settings': 'Django Settings'
}
