export default {
  'index': { display: 'hidden' },
  'architecture': 'Architecture',
  'data-layer': 'Data Layer',
  'ssr-hydration': 'SSR & Hydration',
  'state-management': 'State Management',
  'component-patterns': 'Component Patterns',
  'websocket': 'WebSocket',
  'recipes': 'Recipes',
}
