export default {
  'index': { display: 'hidden' },
  'overview': 'Overview',
  'quick-reference': 'Quick Reference',
  'core-commands': 'Core Commands',
  'codegen': 'Code Generation',
  'development': 'Development',
  'payments': 'Payments',
  'testing-monitoring': 'Testing & Monitoring',
  'maintenance': 'Maintenance'
}
